<?php

require_once('cms/feindura.include.php');

$feindura = new Feindura();

?>
<!doctype html>
<html>
<head>
<?php

    echo $feindura->createMetaTags('John Doe'); // add an author to the meta tags

?>
    <meta name="viewport" content="width=device-width">

    <link rel="stylesheet" href="css/bootstrap.min.css">
    <link rel="stylesheet" href="css/style.css">

    <!--[if lt IE 9]>
    <script src="dist/html5shiv.js"></script>
    <![endif]-->
</head>
<body>

    <!-- IMPORTANT NOTE:

    This Layout uses Bootstrap to make the styling easy.
    Some CSS classes are not in the "style.css", but in the "bootstrap.min.css".
    To learn more about Bootstrap go to: http://twitter.github.com/bootstrap/ -->

    <!-- INTRODUCTION:

    Feindura uses a class based system to make your websites dynamic.
    The class system gives you the most flexibility when creating any type of beautiful website.
    Basically you need only one class, the Feindura class. You instantiate it once and by using its methods, you get all the content you build in the backend.

    The following feindura implementation is just an example, however you can build your own website how you want.
    To get a deeper understanding of these methods take a look at the Feindura class API here:
    http://feindura.org/api/[Implementation]/Feindura.html


    The methods used to create this page are:
    - createMetaTags()          http://feindura.org/api/[Implementation]/Feindura.html#createMetaTags
    - createMenu()              http://feindura.org/api/[Implementation]/Feindura.html#createMenu
    - createSubMenu()           http://feindura.org/api/[Implementation]/Feindura.html#createSubMenu
    - createBreadCrumbsMenu()   http://feindura.org/api/[Implementation]/Feindura.html#createBreadCrumbsMenu
    - showPage()                http://feindura.org/api/[Implementation]/Feindura.html#showPage
    - showPlugins()             http://feindura.org/api/[Implementation]/Feindura.html#showPlugins

    For a simple website you just need the following:
    - createMetaTags()
    - createMenu()
    - showPage()


    The "number" parameters in this methods are the IDs of pages or categories.
    You can only see the IDs of the pages and categories in the backend, when you're logged in as as Administrator (or no user exist).

    It may seem a lot at the beginning, but its simple when you got it! Just take a look at the methods (http://feindura.org/api/%5BImplementation%5D/Feindura.html#sec-method-summary).
    In the description of the methods you will find examples for almost everything.
    The most used methods are:

    - createMetaTags()
    - createLink()
    - createMenu()
    - createBreadCrumbsMenu()
    - showPage()
    - showPlugins()
    - listPages()     http://feindura.org/api/[Implementation]/Feindura.html#listPages

    -->

    <header class="main">
        <div class="container">
            <?php

                // HOW TO BUILD A HEADER
                // ******************************************************


                // HEADER TITLE
                // For the title of our website, we use the title which we set in the website settings in the backend. The property $metaData contains the title, publisher, copyright, keywords and website description.
                // To see what's in the $metaData array take a look here: http://feindura.org/api/[Implementation]/Feindura.html#$metaData
                // We also make the title a link to the start page by calling the createHref() method. See http://feindura.org/api/[Implementation]/Feindura.html#createHref
                echo '<h1><a href="'.$feindura->createHref($feindura->startPage).'">'.$feindura->metaData['title'].'</a></h1>';

            ?>


            <!-- MAIN MENU -->
            <nav role="main">
                <?php

                    // HOW TO BUILD A MENU (with SUB MENU)
                    // ******************************************************


                    // -> create the MENU
                    // Description of createMenu(): http://feindura.org/api/[Implementation]/Feindura.html#createMenu
                    foreach($feindura->createMenu('category',0,'ul.nav.nav-pills') as $item) {
                        echo $item['startTag']; // you could also just call $link['menuItem'] to have <li><a href="..">..</a></li> all together, but thats not working when building an easy CSS based sub menu.
                        echo $item['link'];

                        // -> creates the SUB MENU inside the current <li>, when the current linked page has one
                        // Description of createSubMenu(): http://feindura.org/api/[Implementation]/Feindura.html#createSubMenu
                        foreach ($feindura->createSubMenuOfPage($item['pageId'],'ul.dropdown-menu') as $subItem) {
                            echo $subItem['menuItem'];
                        }

                        echo $item['endTag'];
                    }


                ?>
            </nav>
        </div>
    </header>


    <div class="breadCrumbNav">
        <div class="container">
            <?php

            // HOW TO ADD A BREADCRUMB NAVIGATION
            // ******************************************************


            // -> creates a bread crumb navigation for the current page (thats why is the first parameter "false")
            // Description of createBreadCrumbsMenu(): http://feindura.org/api/[Implementation]/Feindura.html#createBreadCrumbsMenu
            foreach($feindura->createBreadCrumbsMenu(false,' &rarr; ') as $item) {
                echo $item['menuItem'];
            }


            ?>
        </div>
    </div>

    <div class="container">

        <!-- Bootstrap class "row", will allow us to set the size of the inner divs with: "span*" -->
        <article class="row mainContent">
            <?php

            // NOW COMES THE SIDEBAR MENU or SUB MENU
            // ******************************************************


            // -> add a SUB MENU on the left, if the current page has one, or you're on a page inside a subcategory
            if($subMenu = $feindura->createSubMenu('ul.nav.nav-tabs.nav-stacked')) {
                ?>

                <!-- SIDEBAR DIV -->
                <div class="span3">
                <?php
                    foreach ($subMenu as $item) {
                        echo $item['menuItem'];
                    }
                ?>
                </div>
                <?php

                // set the width for the content div, when there is a submenu
                $spanWidth = 9;

            } else {
                // set the width for the content div, span12 = full width
                $spanWidth = 12;
            }


            ?>

            <!-- CONTENT DIV -->
            <div class="span<?php echo $spanWidth; ?>"> <!-- bootstrap class span* to determine the width of the div -->
            <?php



                // AND FINALLY THE CONTENT
                // ******************************************************

                // SHOW THE CONTENT
                // We dont give an id so it will always show the current page were we are on.
                // Description of showPage(): http://feindura.org/api/[Implementation]/Feindura.html#showPage

                // but before we call the showPage method, we set to show the pageDate in the title, when we are in the blog category.
                if($feindura->category == 3) {
                    $feindura->titleShowPageDate = true;
                    $feindura->titlePageDateSeparator = ' - ';
                }

                $currentPage = $feindura->showPage();
                echo '<h1>'.$currentPage['title'].'</h1>';
                // echo $currentPage['thumbnail']; activate thumbnails in the "pageSettings" first and upload a thumbnail per page, to be able to display a thumbnail.
                echo $currentPage['content'];





                // LETS LIST OUR BLOG
                // This method lists only pages, which fit a specific time frame. Pages without a date will not get listet.
                // For more read here: http://feindura.org/api/[Implementation]/Feindura.html#listPageByDate
                if($currentPage['id'] == 10) {


                    $feindura->titleAsLink = true;
                    $pagesWithDate = $feindura->listPageByDate(true,true,'category',$currentPage['subCategoryId'],50);

                    // lets draw separator
                    echo '<br><hr>';

                    // and LIST THE PAGES
                    foreach ($pagesWithDate as $pageWithDate) {
                        echo '<h2>'.$pageWithDate['title'].'</h2>';
                        echo $pageWithDate['pageDate'];
                        echo $pageWithDate['content'];
                        echo '<br><br><hr>';
                    }
                }




                // PLUGINS
                // We could show the plugins, or a specific plugin on a fixed location,
                // but we can also place them directly in the page, using the Editor.
                // Description of showPlugins(): http://feindura.org/api/[Implementation]/Feindura.html#showPlugins
                //
                // foreach($feindura->showPlugins() as $plugin)
                //   echo $plugin;
                //
                // OR
                //
                // echo $feindura->showPlugin('imageGallery'); // will show the imageGallery of the current page


            ?>
            </div>
        </article>


        <footer class="main">
            <hr>
            <div class="row">
                <div class="span6">
                    <p>&copy; <?php echo $feindura->metaData['copyright']; ?></p>
                </div>
                <div class="span6 right">
                    <a href="cms/" class="btn" target="_blank"><i class="icon-edit"></i> CMS Backend</a>
                </div>
            </div>
        </footer>

    </div><!-- /container -->

<!-- Want to use MOOTOOLS? Do it like this when using feindura:
<script>window.MooTools || document.write(unescape('<script src="//ajax.googleapis.com/ajax/libs/mootools/1.4.5/mootools-yui-compressed.js"><\/script>'))</script>
<script>window.MooTools || document.write(unescape('<script src="js/libs/mootools-core-1.4.5.js"><\/script>'))</script>
<script>!window.MooTools.More && window.MooTools && document.write(unescape('<script src="js/libs/mootools-more-1.4.0.1.js"><\/script>'))</script>
-->

<!-- Google Analytics -->
<script>
    var _gaq=[['_setAccount','UA-XXXXX-X'],['_trackPageview']];
    (function(d,t){var g=d.createElement(t),s=d.getElementsByTagName(t)[0];
    g.src=('https:'==location.protocol?'//ssl':'//www')+'.google-analytics.com/ga.js';
    s.parentNode.insertBefore(g,s)}(document,'script'));
</script>

</body>
</html>
